@@ -3,6 +3,9 @@
 This file contains tricks to manipulate symbolic expressions
 """
 
+import sympy as sy
+import numpy as np
+
 def ht_nicepoly(p,x):
     """  
     This function takes a sympy function p, tries to interpret it as
